# Raspberry Pi Pico GPIO Pinout

[![Build Status](https://img.shields.io/github/actions/workflow/status/pinout-xyz/picopins/test.yml?branch=main)](https://github.com/pinout-xyz/picopins/actions/workflows/test.yml)
[![Coverage Status](https://coveralls.io/repos/github/pinout-xyz/picopins/badge.svg?branch=master)](https://coveralls.io/github/pinout-xyz/picopins?branch=master)
[![PyPi Package](https://img.shields.io/pypi/v/picopins.svg)](https://pypi.python.org/pypi/picopins)
[![Python Versions](https://img.shields.io/pypi/pyversions/picopins.svg)](https://pypi.python.org/pypi/picopins)

Generated from [the Pimoroni Python Boilerplate](https://github.com/pimoroni/boilerplate-python).

# Installing

* Just run `python3 -m pip install picopins`